==> worker-2.8.3.tar.bz2: worker-2.8.3/src/dnd.h <==
/* dnd.h
 * This file belongs to Worker, a filemanager for UNIX/X11.
 * Copyright (C) 2001 Ralf Hoffmann.
 * You can contact me at: ralf.hoffmann@epost.de
 *   or http://www.boomerangsworld.de/worker
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/* $Id: dnd.h,v 1.5 2003/11/23 21:20:30 ralf Exp $ */

#ifndef DND_H
#define DND_H

#include "wdefines.h"
#include <aguix/message.h>
#include "datei.h"

class Lister;
class ListerMode;
class Worker;

class DNDMsg
{
public:
  DNDMsg(Worker *worker);
  DNDMsg(Worker *worker,AGDNDSTART s,AGDNDEND e);
  ~DNDMsg();
  FileEntry *getFE();
  const char *getDestDir();
  Lister *getDestLister();
  ListerMode *getDestMode();
  Lister *getSourceLister();
  ListerMode *getSourceMode();

  void setStart(AGDNDSTART*s);
  void setEnd(AGDNDEND*e);
  const AGDNDSTART *getStart();
  const AGDNDEND *getEnd();

protected:
  AGDNDSTART start;
  AGDNDEND end;
  
  Lister *sl,*el;
  ListerMode *slm,*elm;
  
  Worker *worker;
};

#endif

==> worker-2.13.1.tar.bz2: worker-2.13.1/src/dnd.h <==
/* dnd.h
 * This file belongs to Worker, a filemanager for UNIX/X11.
 * Copyright (C) 2001-2004 Ralf Hoffmann.
 * You can contact me at: ralf@boomerangsworld.de
 *   or http://www.boomerangsworld.de/worker
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/* $Id: dnd.h,v 1.8 2004/12/12 21:56:38 ralf Exp $ */

#ifndef DND_H
#define DND_H

#include "wdefines.h"
#include <aguix/message.h>
#include "datei.h"

class Lister;
class ListerMode;
class Worker;

class DNDMsg
{
public:
  DNDMsg(Worker *worker);
  DNDMsg(Worker *worker,AGDNDSTART s,AGDNDEND e);
  ~DNDMsg();
  DNDMsg( const DNDMsg &other );
  DNDMsg &operator=( const DNDMsg &other );

  FileEntry *getFE() const;
  const char *getDestDir() const;
  Lister *getDestLister() const;
  ListerMode *getDestMode() const;
  Lister *getSourceLister() const;
  ListerMode *getSourceMode() const;

  void setStart(AGDNDSTART*s);
  void setEnd(AGDNDEND*e);
  const AGDNDSTART *getStart();
  const AGDNDEND *getEnd();

protected:
  AGDNDSTART start;
  AGDNDEND end;
  
  Lister *sl,*el;
  ListerMode *slm,*elm;
  
  Worker *worker;
};

#endif
